==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/cwindowlist.cpp <==
//
// C++ Implementation: cwindowlist
//
// Description:
//
//
// Author: Tomas Mecir <kmuddy@kmuddy.org>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//

#include "cwindowlist.h"
#include "cconnection.h"
#include "cconnectioninfo.h"
#include "csession.h"

#include "dialogs/dlgoutputwindow.h"

#include <kapplication.h>
#include <kconfig.h>

using namespace std;

cWindowList::cWindowList (QString filename, cSession *s)
{
  sess = s;
  file = filename;
  load ();
}

cWindowList::~cWindowList ()
{
  save ();

  //destroy all windows
  map<QString, dlgOutputWindow *>::iterator it;
  for (it = windows.begin(); it != windows.end(); ++it)
    delete it->second;
  windows.clear ();
}

bool cWindowList::exists (const QString &name)
{
  if (windows.count (name))
    return true;
  return false;
}

bool cWindowList::add (const QString &name, bool autoadd)
{
  if (exists (name)) return false;
  //won't allow empty window name
  if (name.isEmpty()) return false;
  //create the window
  dlgOutputWindow *owin = new dlgOutputWindow ();
  //remember it
  windows[name] = owin;
  owin->setSession(sess);
  owin->setOutputWindowName(name);
  
  //let the window be shown by default, unless added by autorestore
  if(!autoadd)
    owin->show ();
  
  return true;
}

bool cWindowList::remove (const QString &name)
{
  if (!exists (name)) return false;

  //get the window
  dlgOutputWindow *owin = windows[name];
  //hide it
  owin->hide ();
  //delete it
  delete owin;
  //remove it from our mapping
  windows.erase (name);
  //add it to the list of windows, that are to be erased from config-file
  toerase.push_back (name);
  return true;
}

QStringList cWindowList::windowList ()
{
  QStringList lst;
  map<QString, dlgOutputWindow *>::iterator it;
  for (it = windows.begin(); it != windows.end(); ++it)
    lst.push_back (it->first);
  return lst;
}

bool cWindowList::show (const QString &name)
{
  if (!exists (name)) return false;

  dlgOutputWindow *owin = windows[name];

  owin->show ();
  return true;
}

bool cWindowList::hide (const QString &name)
{
  if (!exists (name)) return false;

  dlgOutputWindow *owin = windows[name];

  owin->hide ();
  return true;
}

void cWindowList::toggle (const QString &name)
{
  if (!exists (name)) return;
  if (windows[name]->isVisible())
    windows[name]->hide ();
  else
    windows[name]->show ();
}

bool cWindowList::isShown (const QString &name)
{
  if (!exists (name)) return false;
  return windows[name]->isVisible();
}

void cWindowList::textToWindow (const QString &name, cTextChunk *chunk)
{
  if (!exists (name)) return;

  //add text to the window
  windows[name]->addLine(chunk);
}

void cWindowList::load ()
{
  QStringList groups;
  QPoint pos;
  bool vis;

  KConfig *config = new KConfig (file, true);

  groups = config->groupList();

  if(groups.empty() == true)
    return;

  //traverse through list of groups, loading each window
  for ( QStringList::Iterator it = groups.begin(); it != groups.end(); ++it )
    {
      name = *it;
      if(name.find("KMuddywin_", 0) != -1)
      {
        config->setGroup (name);
        name.replace("KMuddywin_", QString::null);
        if(!add(name, true))
          return;
        windows[name]->setInitialSize(config->readSizeEntry("Size"));
        pos = config->readPointEntry("Position");
        windows[name]->move(pos);
        vis = config->readBoolEntry("Visible");
        if(vis)
          show(name);
      }
    }
  delete config;
}

void cWindowList::save ()
{
  KConfig *config = new KConfig (file);

  //erase removed windows from the configfile
  if(!toerase.empty())
  {
    for(QStringList::Iterator it = toerase.begin(); it != toerase.end(); ++it)
    {
      config->deleteGroup("KMuddywin_"+*it);
    }
  }

  //save all windows
  map<QString, dlgOutputWindow *>::iterator it;
  for (it = windows.begin(); it != windows.end(); ++it)
  {
    config->setGroup ("KMuddywin_"+it->first);
    config->writeEntry("Size", it->second->size());
    config->writeEntry("Position", it->second->pos());
    config->writeEntry("Visible", it->second->isVisible());
  }

  delete config;
}

void cWindowList::adjustFonts(QFont font)
{
  map<QString, dlgOutputWindow *>::iterator it;
  for (it = windows.begin(); it != windows.end(); ++it)
  {
    it->second->setFont(font);
  }
}

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/cwindowlist.cpp <==
//
// C++ Implementation: cwindowlist
//
// Description:
//
//
// Author: Tomas Mecir <kmuddy@kmuddy.net>, (C) 2004
//
// Copyright: See COPYING file that comes with this distribution
//
//

#include "cwindowlist.h"

#include "cglobalsettings.h"
#include "cconsole.h"
#include "dialogs/dlgoutputwindow.h"

#include <kapplication.h>
#include <kconfig.h>

using namespace std;

extern cGlobalSettings *globalsettings;

cWindowList::cWindowList (QString filename, int sess)
  : cActionBase ("windowlist", sess)
{
  file = filename;
  load ();
}

cWindowList::~cWindowList ()
{
  save ();

  //destroy all windows
  map<QString, dlgOutputWindow *>::iterator it;
  for (it = windows.begin(); it != windows.end(); ++it)
    delete it->second;
  windows.clear ();
}

bool cWindowList::exists (const QString &name)
{
  if (windows.count (name))
    return true;
  return false;
}

bool cWindowList::add (const QString &name, bool autoadd)
{
  if (exists (name)) return false;
  //won't allow empty window name
  if (name.isEmpty()) return false;
  //create the window
  dlgOutputWindow *owin = new dlgOutputWindow (KApplication::kApplication()->mainWidget());
  //remember it
  windows[name] = owin;
  owin->setSession (sess());
  owin->setOutputWindowName(name);
  
  //let the window be shown by default, unless added by autorestore
  if(!autoadd)
    owin->show ();
  
  // set settings
  globalsettings->apply();

  return true;
}

bool cWindowList::remove (const QString &name)
{
  if (!exists (name)) return false;

  //get the window
  dlgOutputWindow *owin = windows[name];
  //hide it
  owin->hide ();
  //delete it
  delete owin;
  //remove it from our mapping
  windows.erase (name);
  //add it to the list of windows, that are to be erased from config-file
  toerase.push_back (name);
  return true;
}

QStringList cWindowList::windowList ()
{
  QStringList lst;
  map<QString, dlgOutputWindow *>::iterator it;
  for (it = windows.begin(); it != windows.end(); ++it)
    lst.push_back (it->first);
  return lst;
}

bool cWindowList::show (const QString &name)
{
  if (!exists (name)) return false;

  dlgOutputWindow *owin = windows[name];

  owin->show ();
  return true;
}

bool cWindowList::hide (const QString &name)
{
  if (!exists (name)) return false;

  dlgOutputWindow *owin = windows[name];

  owin->hide ();
  return true;
}

void cWindowList::toggle (const QString &name)
{
  if (!exists (name)) return;
  if (windows[name]->isVisible())
    windows[name]->hide ();
  else
    windows[name]->show ();
}

bool cWindowList::isShown (const QString &name)
{
  if (!exists (name)) return false;
  return windows[name]->isVisible();
}

void cWindowList::textToWindow (const QString &name, cTextChunk *chunk)
{
  if (!exists (name)) return;

  //add text to the window
  windows[name]->addLine(chunk);
  // switch-window is used, so that others can determine which window was used
  // main output emits the same signal, prepended with switch-window with
  // an empty string
  invokeEvent ("switch-window", sess(), name);
  invokeEvent ("displayed-line", sess(), chunk);
}

void cWindowList::load ()
{
  QStringList groups;
  QPoint pos;
  bool vis;

  KConfig *config = new KConfig (file, true);

  groups = config->groupList();

  if(groups.empty() == true)
    return;

  //traverse through list of groups, loading each window
  for ( QStringList::Iterator it = groups.begin(); it != groups.end(); ++it )
    {
      name = *it;
      if(name.find("KMuddywin_", 0) != -1)
      {
        config->setGroup (name);
        name.replace("KMuddywin_", QString::null);
        if(!add(name, true))
          return;
        windows[name]->setInitialSize(config->readSizeEntry("Size"));
        pos = config->readPointEntry("Position");
        windows[name]->move(pos);
        vis = config->readBoolEntry("Visible");
        if(vis)
          show(name);
      }
    }
  delete config;
}

void cWindowList::save ()
{
  KConfig *config = new KConfig (file);

  //erase removed windows from the configfile
  if(!toerase.empty())
  {
    for(QStringList::Iterator it = toerase.begin(); it != toerase.end(); ++it)
    {
      config->deleteGroup("KMuddywin_"+*it);
    }
  }

  //save all windows
  map<QString, dlgOutputWindow *>::iterator it;
  for (it = windows.begin(); it != windows.end(); ++it)
  {
    config->setGroup ("KMuddywin_"+it->first);
    config->writeEntry("Size", it->second->size());
    config->writeEntry("Position", it->second->pos());
    config->writeEntry("Visible", it->second->isVisible());
  }

  delete config;
}

void cWindowList::adjustFonts(QFont font)
{
  map<QString, dlgOutputWindow *>::iterator it;
  for (it = windows.begin(); it != windows.end(); ++it)
  {
    it->second->setFont(font);
  }
}

void cWindowList::applySettings (bool allowblinking, bool wordwrapping,
    int wrappos, int indentvalue, int forceredraw)
{
  map<QString, dlgOutputWindow *>::iterator it;
  for (it = windows.begin(); it != windows.end(); ++it)
  {
    cConsole *console = it->second->console();
    console->setEnableBlinking (allowblinking);
    console->setWordWrapping (wordwrapping);
    console->setWrapPos (wrappos);
    console->setIndentation (indentvalue);
    console->setRepaintCount (forceredraw);
  }
}
